export function hexadecimalToTypedArray(hexadecimal) {
    const arr = new Uint8Array(hexadecimal.length / 2);
    for (let i = 0; i < hexadecimal.length; i += 2) {
        arr[i / 2] = parseInt(hexadecimal.substring(i, i + 2), 16);
    }
    return arr;
}
export function base64Encode(str) {
    const bytes = new Uint8Array(str.length);
    for (let i = 0; i < str.length; ++i) {
        bytes[i] = str.charCodeAt(i);
    }
    let base64 = '';
    const encodings = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
    for (let i = 0; i < bytes.length; i += 3) {
        const b1 = bytes[i];
        const b2 = (i + 1 < bytes.length ? bytes[i + 1] : 0);
        const b3 = (i + 2 < bytes.length ? bytes[i + 2] : 0);
        const n1 = b1 >> 2;
        const n2 = ((b1 & 3) << 4) | (b2 >> 4);
        const n3 = ((b2 & 15) << 2) | (b3 >> 6);
        const n4 = b3 & 63;
        base64 +=
            encodings[n1] +
                encodings[n2] +
                (i + 1 < bytes.length ? encodings[n3] : '=') +
                (i + 2 < bytes.length ? encodings[n4] : '=');
    }
    return base64;
}
export function stringToByteArray(str) {
    const bytes = [];
    for (let i = 0; i < str.length; i++) {
        bytes.push(str.charCodeAt(i));
    }
    return new Uint8Array(bytes);
}
export async function toArray(generator) {
    const arr = [];
    for await (const item of generator) {
        arr.push(item);
    }
    return arr;
}
export const filePathsToTree = (paths) => {
    const results = [];
    return paths.reduce((currentResults, currentPath) => {
        const pathParts = currentPath.split('/');
        const byPath = {};
        pathParts.reduce((nodes, name, index, arr) => {
            let node = nodes.find((node) => node.name === name);
            const path = arr.slice(0, index + 1).join('/');
            const parentPath = arr.slice(0, index).join('/');
            if (!node) {
                node = {
                    name,
                    path,
                    parent: byPath[parentPath] || null,
                    children: [],
                };
                nodes.push(node);
            }
            byPath[path] = node;
            return node.children;
        }, currentResults);
        return currentResults;
    }, results);
};
export const treeToString = (nodes, level = 0, prefix = '') => {
    const nodesCount = nodes.length - 1;
    let results = '';
    nodes.forEach((node, nodeIndex) => {
        let line = node.name;
        let pointer = '';
        if (level > 0) {
            if (nodesCount > 0) {
                pointer = nodeIndex === nodesCount ? '└── ' : '├── ';
            }
            else {
                pointer = '└── ';
            }
        }
        results += prefix + pointer + line + '\n';
        if (node.children && node.children.length) {
            let newPrefix = prefix;
            if (level > 0) {
                newPrefix += `${nodeIndex === nodesCount ? ' ' : '│'}   `;
            }
            results += treeToString(node.children, level + 1, newPrefix);
        }
    });
    return results;
};
export const printFilePathsAsTree = (paths) => {
    console.log(treeToString(filePathsToTree(paths)));
};
//# sourceMappingURL=util.js.map